#!/usr/bin/perl
#
# Copyright (C) 2023 Juan Domingo (Juan.Domingo@uv.es)
#
# This script is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
use strict;
use warnings;

($#ARGV == 0) || die("Usage: $0 <simplified_ATC_file.csv>\n");

open(F,"<$ARGV[0]") || die("Cannot open csv input file.\n");

my $line;
my $i=1;
my $url;
my $code;
my $name;
my %all;
while (defined($line=<F>))
{
 chomp($line);
 if ($line =~ /\"([^\"]+)\"\,\"([^\"]+)\"/)
 {
  $url=$1;
  $name=$2;
  if ($url =~ /\/([^\/]+)$/)
  {
   $code=$1;
   if (!exists($all{$code}))
   {
    $all{$code}=$name;
   }
   else
   {
    print "Error in line $i: duplicated code $code\n";
   }
  }
  else
  {
   print "Unexpected URL format at line $i\n";
  }
 }
 else
 {
  print "Warning: unexpected format in line $i";
 }
 $i++;
}
print "$i lines read.\n";
close(F);

my $maxlen=0;
open(G,">ATClist.txt") || die("Cannot open file ATClist.txt to write.\n");
open(H,">FillDrug.sql") || die("Cannot open file FillDrug.sql to write.\n");
foreach my $item(sort(keys(%all)))
{
 print G "$item";
 print G ' ' x (8-length($item));
 print G "$all{$item}\n";
 # This condition is elliminated. Not only final drugs, but also classes of them, will be added.
 #if (length($item)>=7)
 #{
  print H "INSERT INTO Drug VALUES('".$item."','".$all{$item}."');\n";
  if (length($all{$item})>$maxlen)
  {
   $maxlen=length($all{$item});
  }
 #}
}
close(G);
close(H);
print "The maximum length of a drug name is $maxlen characters.\n";


